@@ -23,7 +23,12 @@
 
 #--------------------------------------------------------------------------------------
 """
-This script is responsible for cluster environment setup for the given Amazon EC2 reservation
+Launches a solver defined by the given solver ''case''. 
+Results of the solver work can be obtained by usage of ''[[cloudflu-solver-process]]'' 
+utility. These two utility was specially designed not just run together, 
+but do their work in parallel. The common entry point for both of these utilities 
+is ''study'', which could be reserver in advance by calling ''[[cloudflu-study-book]]'' 
+utility.
 """
 
 
@@ -106,6 +111,10 @@ def main() :
     a_host_port = int( get( 'amazon.cluster.host_port' ) )
     a_login_name = get( 'amazon.cluster.login_name' )
 
+    a_watched_keyword = get( 'amazon.timestamps_upload.watched_keyword' )
+    a_watching_timeout = get( 'amazon.timestamps_upload.watching_timeout' )
+    a_finish_hook = get( 'amazon.timestamps_upload.finish_hook' )
+
 
     print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
     import sys; an_engine = sys.argv[ 0 ]
@@ -189,13 +198,19 @@ def main() :
     an_additional_args = "--booked"
     an_additional_args += " --study-name='%s'" % ( a_study_name )
     an_additional_args += " --upload-seed-size=%d" % ( an_upload_seed_size )
+    an_additional_args += " --watched-keyword='%s'" % ( a_watched_keyword )
+    if a_watching_timeout != None :
+        an_additional_args += " --watching-timeout=%d" % ( a_watching_timeout )
+        pass
+    an_additional_args += " --finish-hook='%s'" % ( a_finish_hook )
 
     a_command = "%s/%s %d '%s' %s" % ( a_target_dir, a_run_hook, a_num_nodes, a_hostfile, an_additional_args )
 
     if a_wait_run == False :
         a_host_name = a_master_node.public_dns_name
         a_ssh = ssh.options.command( a_password, an_identity_file, a_host_port, a_login_name, a_host_name )
-        a_ssh += ' -n -f "source /etc/profile && nohup %s > /dev/null 2>&1 &"' % a_command
+        import os.path; a_log_file = os.path.join( a_working_dir, 'log.%s' % a_run_hook )
+        a_ssh += ' -n -f "source /etc/profile && nohup %s > %s 2>&1 &"' % ( a_command, a_log_file )
         print_d( '%s\n' % a_ssh )
 
         import os; os.system( a_ssh )
