@@ -100,13 +100,23 @@ def dump_resume( the_identation_level, the_option_group, the_output ) :
         if not isinstance( an_option, PersistentOption ) :
             continue
         
-        a_default = an_option.default
         a_dest = an_option.dest
+        a_default = an_option.default
+        a_namespace = the_option_group.get_namespace()
 
-        if a_dest in [ 'cluster_location', 'image_id', 'data_location', 'enable_debug', 'production', 'instance_type', 'wait_run' ] :
+        if a_dest in [ 'enable_debug', 'production', 'image_id', 'instance_type', 'wait_run' ] :
             a_default = 'a_helper.%s()' % a_dest
+        elif a_namespace == 'amazon.cluster' :
+            if a_dest in [ 'location', ] :
+                a_default = 'a_helper.cluster_%s()' % a_dest
+                pass
             pass
-
+        elif a_namespace == 'amazon.data_transfer' :
+            if a_dest in [ 'location' ] :
+                a_default = 'a_helper.data_%s()' % a_dest
+                pass
+            pass           
+        
         a_metavar = an_option.metavar
         # a_metavar = a_metavar.title()
         a_metavar = a_metavar.replace( '< ', '' )
@@ -180,10 +190,10 @@ def pickup() :
     import os.path;
     an_rcfilename = os.path.expanduser( an_rcfilename )
     an_rcfilename = os.path.abspath( an_rcfilename )
-    if not os.path.isfile( an_rcfilename ) :
+    if not os.path.isfile( an_rcfilename ) or os.path.getsize( an_rcfilename ) == 0 :
         # If resource file does not exist - write a predefined one
         an_rcfile = open( an_rcfilename, "w" )
-        import cloudflu; an_rcfile.write( """
+        a_header = """
 #--------------------------------------------------------------------------------------
 ## Copyright 2010 Alexey Petrov
 ##
@@ -206,39 +216,60 @@ def pickup() :
 
 
 #--------------------------------------------------------------------------------------
-REGION2PARAMS = { 'us-east-1' : [ '', { 'openfoam171_0-1ubuntu2' : 'ami-ecf50385', 
-                                        'openfoam171_0-1' : 'ami-62fa0c0b', 
-                                        'openfoam-dev-1.5' : 'ami-98f701f1',
-                                        'openfoam-1.6-ext' : 'ami-b2fd0cdb' } ],
-                  'eu-west-1' : [ 'EU', { 'openfoam171_0-1ubuntu2' : 'ami-519ca925',
-                                          'openfoam171_0-1' :'ami-8d9da8f9',
-                                          'openfoam-dev-1.5' : 'ami-4d9ca939',
-                                          'openfoam-1.6-ext' : 'ami-f998ad8d'} ],
-                  'ap-southeast-1' : [ 'ap-southeast-1', { 'openfoam171_0-1ubuntu2' : 'ami-d2423c80',
-                                                           'openfoam171_0-1' :'ami-28423c7a',
-                                                           'openfoam-dev-1.5' : 'ami-2c423c7e',
-                                                           'openfoam-1.6-ext' : 'ami-3a433d68' } ],
-                  'us-west-1' : [ 'us-west-1', { 'openfoam171_0-1ubuntu2' : 'ami-bb7e2efe',
-                                                 'openfoam171_0-1' : 'ami-8d7e2ec8',
-                                                 'openfoam-dev-1.5' : 'ami-a97e2eec',
-                                                 'openfoam-1.6-ext' : 'ami-5f60301a'} ] }
+EC2_TO_S3_REGION = { 'us-east-1' : '', 
+                     'eu-west-1' : 'EU', 
+                     'ap-southeast-1' : 'ap-southeast-1',
+                     'us-west-1' : 'us-west-1' }
+
+
+#--------------------------------------------------------------------------------------
+KERNEL_TO_AMI = { 'hvm' : { 'openfoam200_0-1' : 'ami-4fad6a26' },
+                  'paravirtual' : { 'openfoam200_0-1' : 'ami-e9965180' } }
+
+
+#--------------------------------------------------------------------------------------
+# See detailed information about the available instances types at 
+# http://aws.amazon.com/ec2/instance-types 
+KERNEL_TO_INSTANCE_TYPE = { 'hvm' : set( [ 'cc1.4xlarge' ] ),
+                            'paravirtual' : set( [ 't1.micro', 
+                                                   'c1.xlarge', 
+                                                   'm1.large', 
+                                                   'm1.xlarge', 
+                                                   'm2.xlarge', 
+                                                   'm2.2xlarge', 
+                                                   'm2.4xlarge' ] ) }
 
 
 #--------------------------------------------------------------------------------------
 class Helper :
-    def __init__( self, the_ec2_region, the_openfoam_version, the_debug = False, the_develop = False ) :
+    def __init__( self, the_instance_type = 'cc1.4xlarge', 
+                  the_openfoam_version = 'openfoam200_0-1',
+                  the_ec2_region = 'us-east-1',
+                  the_debug = True, 
+                  the_develop = True ) :
+        if not the_ec2_region in EC2_TO_S3_REGION.keys() :
+            raise LookupError( "There is no such location as '%%s' in Amazaon EC2" %%
+                               ( the_ec2_region ) )
         self._cluster_location = the_ec2_region
-        self._data_location = REGION2PARAMS[ the_ec2_region ][ 0 ]
-        self._image_id = REGION2PARAMS[ the_ec2_region ][ 1 ][ the_openfoam_version ]
+
+        self._data_location = EC2_TO_S3_REGION[ the_ec2_region ]
+
+        self._image_id = None
+        for a_kernel, an_instance_types in KERNEL_TO_INSTANCE_TYPE.items() :
+            if the_instance_type in an_instance_types :
+                self._image_id = KERNEL_TO_AMI[ a_kernel ][ the_openfoam_version ]
+                pass
+            pass
+        
+        if self._image_id == None :
+            raise LookupError( "Can not find AMI for the given instance type (%%s)"
+                               " and OpenFOAM version (%%s)" %% ( the_instance_type, 
+                                                                the_openfoam_version ) )
+        self._instance_type = the_instance_type
 
         self._enable_debug = the_debug
         self._develop = the_develop
 
-        self._instance_type = 'c1.xlarge'
-        if the_debug == True :
-            self._instance_type = 'm1.large'
-            pass
-
         pass
 
     def cluster_location( self ) :
@@ -260,17 +291,18 @@ class Helper :
         return self._instance_type
     
     def wait_run( self ) :
-        return self._enable_debug
+        return self._develop
     
     pass
 
 
 #--------------------------------------------------------------------------------------
-a_helper = Helper( 'us-east-1', 'openfoam171_0-1ubuntu2' )
+a_helper = Helper()
 
 
 #--------------------------------------------------------------------------------------
-""" % ( cloudflu.NAME, cloudflu.VERSION ) )
+"""
+        import cloudflu; an_rcfile.write( a_header % ( cloudflu.NAME, cloudflu.VERSION ) )
 
         import cStringIO
         an_output = cStringIO.StringIO()
